(self.webpackJsonp=self.webpackJsonp||[]).push([[39],{866:function(e,r,n){"use strict";n.r(r),n.d(r,"codeMirror",(function(){return c})),n.d(r,"codeMirrorCss",(function(){return i}));var s=n(544),o=n.n(s),t=n(751),a=(n(752),n(753),n(12));o.a.commands.save=e=>{Object(a.a)(e.getWrapperElement(),"editor-save")};const c=o.a,i=t.a}}]);
//# sourceMappingURL=chunk.fe7d7d605c355e5e1188.js.map