(self.webpackJsonp=self.webpackJsonp||[]).push([[43],{872:function(e,r,n){"use strict";n.r(r),n.d(r,"codeMirror",(function(){return c})),n.d(r,"codeMirrorCss",(function(){return i}));var a=n(467),o=n.n(a),s=n(757),t=(n(758),n(759),n(12));o.a.commands.save=function(e){Object(t.a)(e.getWrapperElement(),"editor-save")};var c=o.a,i=s.a}}]);
//# sourceMappingURL=chunk.8b246ac8e4dfb96fc5f5.js.map